""" 
This script tests the ability of a flowline to match inflow above the flowline by
 creating constant inflow of 1 m3/sec onto a 5m dia circle at the head of a 20m
 wide plane dipping at 1:300 with a flowline and gauge downstream of the inflow.



"""

#------------------------------------------------------------------------------
# Import necessary modules
#------------------------------------------------------------------------------
from anuga.abstract_2d_finite_volumes.mesh_factory import rectangular_cross
from anuga.shallow_water import Domain
from anuga.shallow_water.shallow_water_domain import Reflective_boundary
from anuga.shallow_water.shallow_water_domain import Dirichlet_boundary
from anuga.shallow_water.shallow_water_domain import Inflow
from anuga.shallow_water.data_manager import get_flow_through_cross_section
from anuga.abstract_2d_finite_volumes.util import sww2csv_gauges, csv2timeseries_graphs



#------------------------------------------------------------------------------
# Setup computational domain
#------------------------------------------------------------------------------



length = 300.
width  = 20.

dx = dy = 1             # Resolution: of grid on both axes


points, vertices, boundary = rectangular_cross(int(length/dx), int(width/dy),
                                               len1=length, len2=width)
domain = Domain(points, vertices, boundary)   
domain.set_name('inflow_flowline_test')     # Output name
domain.set_default_order(2)
domain.H0 = 0.01
domain.tight_slope_limiters = 1

print 'Size', len(domain)

#------------------------------------------------------------------------------
# Setup initial conditions
#------------------------------------------------------------------------------

def topography(x, y):

    # General Slope of plane is 1:100
    z=-x/300
    return z


domain.set_quantity('elevation', topography)  # Use function for elevation
domain.set_quantity('friction', 0.012)        # Constant friction of conc surface
domain.set_quantity('stage',
                    expression='elevation')   # Dry initial condition

#
#------------------------------------------------------------------------------
# Setup boundary conditions
#------------------------------------------------------------------------------

Br = Reflective_boundary(domain)              # Solid reflective wall
Bo = Dirichlet_boundary([-0.9, 0, 0])           # Outflow stsge at -0.9m d=0.1m

domain.set_boundary({'left': Br, 'right': Bo, 'top': Br, 'bottom': Br})

#------------------------------------------------------------------------------
# Seup Inflow
#------------------------------------------------------------------------------


fixed_inflow = Inflow(domain,
                      center=(10.0, 10.0),
                      radius=5.00,
                      rate=1.00)   # Fixed Flowrate onto Area 

domain.forcing_terms.append(fixed_inflow)


#------------------------------------------------------------------------------
# Evolve system through time
#------------------------------------------------------------------------------

for t in domain.evolve(yieldstep = 5.0, finaltime = 300):
    domain.write_time()  


#------------------------------------------------------------------------------
# Compute flow thru flowline ds of inflow
#------------------------------------------------------------------------------

time, Q = get_flow_through_cross_section('inflow_flowline_test.sww',
                                         [[30.0,0.0],[30.0,20.0]],
                                         verbose=True)
csv_fid= open('inflow_flowline_test.csv', 'w')
for j in range(len(time)):
    csv_fid.write('%f, %f\n' %(time[j], Q[j]))
csv_fid.close()

#------------------------------------------------------------------------------
# Record stage hydrograph ds of inflow
#------------------------------------------------------------------------------

sww2csv_gauges('inflow_flowline_test.sww',
               'gauges.csv',
               quantities=['stage','elevation'],
               verbose=True)
